<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Выбрать приложение</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Установленные приложения</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Своя команда</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Выполняемая командная строка:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="62"/>
        <source>Application name:</source>
        <translation>Имя приложения:</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="72"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Эти спец. коды могут быть использованы в командной строке:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Означает имя одного файла&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Означает имена нескольких файлов&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Означает один URI файла&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Означает несколько URI файлов&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="91"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Не закрывать окно терминала после выполнения команды</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="98"/>
        <source>Execute in terminal emulator</source>
        <translation>Запустить в эмуляторе терминала</translation>
    </message>
    <message>
        <location filename="../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Использовать выбранное приложение как действие по умолчанию для файлов этого типа</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Изменить закладки</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="42"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="47"/>
        <source>Location</source>
        <translation>Расположение</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="67"/>
        <source>&amp;Add Item</source>
        <translation>&amp;Добавить элемент</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="77"/>
        <source>&amp;Remove Item</source>
        <translation>&amp;Удалить элемент</translation>
    </message>
    <message>
        <location filename="../edit-bookmarks.ui" line="102"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Перетаскивайте элементы мышкой, чтобы изменить их порядок</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Выполнить файл</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="39"/>
        <source>&amp;Open</source>
        <translation>&amp;Открыть</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="52"/>
        <source>E&amp;xecute</source>
        <translation>В&amp;ыполнить</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="62"/>
        <source>Execute in &amp;Terminal</source>
        <translation>Выполнить в &amp;терминале</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="85"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../exec-file.ui" line="99"/>
        <source>Remember for next files of this kind</source>
        <translation>Запомнить для следующих файлов этого типа</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../filedialog.ui" line="22"/>
        <source>Path:</source>
        <translation>Путь:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="65"/>
        <source>File name:</source>
        <translation>Имя файла:</translation>
    </message>
    <message>
        <location filename="../filedialog.ui" line="75"/>
        <source>File type:</source>
        <translation>Тип файла:</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../file-operation-dialog.ui" line="32"/>
        <source>Destination:</source>
        <translation>Назначение:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="55"/>
        <source>Processing:</source>
        <translation>Обработка:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="68"/>
        <source>Preparing...</source>
        <translation>Подготовка...</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="75"/>
        <source>Progress</source>
        <translation>Прогресс</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="95"/>
        <source>Time remaining:</source>
        <translation>Времени осталось:</translation>
    </message>
    <message>
        <location filename="../file-operation-dialog.ui" line="125"/>
        <source>Files processed:</source>
        <translation>Обработано файлов:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Свойства файла</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Расположение:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="106"/>
        <source>File type:</source>
        <translation>Тип файла:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="129"/>
        <source>MIME type:</source>
        <translation>Тип Mime:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="152"/>
        <source>File size:</source>
        <translation>Размер файла:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="175"/>
        <source>On-disk size:</source>
        <translation>Размер на диске:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="198"/>
        <source>Last modified:</source>
        <translation>Последнее изменение:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="221"/>
        <source>Link target:</source>
        <translation>Цель ссылки:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="247"/>
        <source>Open With:</source>
        <translation>Открыть с помощью:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="264"/>
        <source>Last accessed:</source>
        <translation>Последний доступ:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="287"/>
        <source>Created:</source>
        <translation>Создан:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="310"/>
        <source>Contains:</source>
        <translation>Содержимое:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="330"/>
        <source>Emblem:</source>
        <translation>Эмблема:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="342"/>
        <source>Choose emblem</source>
        <translation>Выберите эмблему</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="361"/>
        <source>Clear emblem</source>
        <translation>Очистить эмблему</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="414"/>
        <source>Device Usage:</source>
        <translation>Свободно на диске:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="424"/>
        <source>Permissions</source>
        <translation>Разрешения</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="439"/>
        <source>Ownership</source>
        <translation>Владение</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="463"/>
        <location filename="../file-props.ui" line="528"/>
        <location filename="../file-props.ui" line="642"/>
        <source>Group:</source>
        <translation>Группа:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="476"/>
        <location filename="../file-props.ui" line="511"/>
        <location filename="../file-props.ui" line="590"/>
        <source>Owner:</source>
        <translation>Владелец:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="492"/>
        <source>Access Control</source>
        <translation>Контроль доступа</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="545"/>
        <location filename="../file-props.ui" line="694"/>
        <source>Other:</source>
        <translation>Остальные:</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="562"/>
        <source>Make the file executable</source>
        <translation>Сделать файл исполняемым</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="603"/>
        <location filename="../file-props.ui" line="655"/>
        <location filename="../file-props.ui" line="707"/>
        <source>Read</source>
        <translation>Чтение</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="616"/>
        <location filename="../file-props.ui" line="668"/>
        <location filename="../file-props.ui" line="720"/>
        <source>Write</source>
        <translation>Запись</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="629"/>
        <location filename="../file-props.ui" line="681"/>
        <location filename="../file-props.ui" line="733"/>
        <source>Execute</source>
        <translation>Выполнение</translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="742"/>
        <source>Sticky</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="749"/>
        <source>SetUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="756"/>
        <source>SetGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../file-props.ui" line="792"/>
        <source>Advanced Mode</source>
        <translation>Расширенный режим</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../appchoosercombobox.cpp" line="66"/>
        <source>Customize</source>
        <translation>Настроить</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../appchooserdialog.cpp" line="268"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>Выберите приложение, чтобы открыть &quot;%1&quot; файлов</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../createnewmenu.cpp" line="62"/>
        <source>Folder</source>
        <translation>Папку</translation>
    </message>
    <message>
        <location filename="../createnewmenu.cpp" line="66"/>
        <source>Blank File</source>
        <translation>Пустой файл</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../core/dirlistjob.cpp" line="48"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation>Указанный каталог &apos;%1&apos; некорректен</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="84"/>
        <source>Loading...</source>
        <translation>Загрузка...</translation>
    </message>
    <message>
        <location filename="../dirtreemodelitem.cpp" line="267"/>
        <location filename="../dirtreemodelitem.cpp" line="311"/>
        <location filename="../dirtreemodelitem.cpp" line="409"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;Нет подпапок&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../dirtreeview.cpp" line="217"/>
        <source>Open in New T&amp;ab</source>
        <translation>Открыть в новой вкл&amp;адке</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="221"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Открыть в новом о&amp;кне</translation>
    </message>
    <message>
        <location filename="../dirtreeview.cpp" line="226"/>
        <source>Open in Termina&amp;l</source>
        <translation>Открыть в термина&amp;ле</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>Копировать сюда</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>Переместить сюда</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>Создать здесь ссылку</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../dndactionmenu.cpp" line="42"/>
        <source>Cannot drop here</source>
        <translation>Невозможно перенести сюда</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../editbookmarksdialog.cpp" line="84"/>
        <source>New bookmark</source>
        <translation>Новая закладка</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../execfiledialog.cpp" line="40"/>
        <source>This file &apos;%1&apos; seems to be a desktop entry.
What do you want to do with it?</source>
        <translation>Файл «%1» является .desktop-файлом.
Что вы хотите с ним сделать?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="46"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>Этот текстовый файл &apos;%1&apos; похож на исполняемый скрипт.
Что вы хотите с ним сделать?</translation>
    </message>
    <message>
        <location filename="../execfiledialog.cpp" line="51"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>Файл &apos;%1&apos; является исполняемым. Вы хотите запустить его?</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialog</name>
    <message>
        <location filename="../filedialog.cpp" line="105"/>
        <source>Go Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="106"/>
        <source>Alt+Left</source>
        <comment>Go Back</comment>
        <translation>Alt+Влево</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="112"/>
        <source>Go Forward</source>
        <translation>Вперед</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="113"/>
        <source>Alt+Right</source>
        <comment>Go Forward</comment>
        <translation>Alt+Вправо</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="120"/>
        <source>Reload</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="121"/>
        <source>F5</source>
        <comment>Reload</comment>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="138"/>
        <source>Create Folder</source>
        <translation>Создать папку</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="154"/>
        <source>Icon View</source>
        <translation>В виде значков</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="158"/>
        <source>Thumbnail View</source>
        <translation>В виде эскизов</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="162"/>
        <source>Compact View</source>
        <translation>Компактно</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="166"/>
        <source>Detailed List View</source>
        <translation>В виде подробного списка</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="174"/>
        <source>Icon Sizes</source>
        <translation>Размер значков</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="176"/>
        <source>Size of big icons:</source>
        <translation>Размер больших значков:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="183"/>
        <source>Size of small icons:</source>
        <translation>Размер маленьких значков:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="190"/>
        <source>Size of thumbnails:</source>
        <translation>Размер миниатюр:</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="206"/>
        <source>Show Hidden</source>
        <translation>Показать скрытые</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="218"/>
        <source>Show Thumbnails</source>
        <translation>Показывать миниатюры</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="223"/>
        <source>Show File Tooltips</source>
        <translation>Показывать подсказки для файлов</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="230"/>
        <source>Smooth Scrolling</source>
        <translation>Плавная прокрутка</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="245"/>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="595"/>
        <location filename="../filedialog.cpp" line="990"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="595"/>
        <source>Please select a file</source>
        <translation>Выберите файл</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="637"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 уже существует.
Вы хотите заменить его?</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="960"/>
        <source>Path &quot;%1&quot; does not exist</source>
        <translation>Путь «%1» не существует</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="974"/>
        <source>&quot;%1&quot; is not a directory</source>
        <translation>«%1» не является каталогом</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="980"/>
        <source>&quot;%1&quot; is not a file</source>
        <translation>«%1» не является файлом</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1132"/>
        <location filename="../filedialog.cpp" line="1240"/>
        <source>&amp;Open</source>
        <translation>&amp;Открыть</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1135"/>
        <location filename="../filedialog.cpp" line="1248"/>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <location filename="../filedialog.cpp" line="1142"/>
        <source>All Files (*)</source>
        <translation>Все файлы (*)</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogHelper</name>
    <message>
        <location filename="../filedialoghelper.cpp" line="138"/>
        <source>Open File</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <location filename="../filedialoghelper.cpp" line="139"/>
        <source>Save File</source>
        <translation>Сохранить файл</translation>
    </message>
</context>
<context>
    <name>Fm::FileDialogIconSizeAction</name>
    <message>
        <location filename="../filedialog_p.h" line="40"/>
        <source> px</source>
        <translation> пикс</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../filemenu.cpp" line="86"/>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="90"/>
        <source>Open With...</source>
        <translation>Открыть с помощью...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="356"/>
        <source>Many files</source>
        <translation>Несколько файлов</translation>
    </message>
    <message numerus="yes">
        <location filename="../filemenu.cpp" line="357"/>
        <source>Do you want to open these %1 files?</source>
        <translation>
            <numerusform>Вы хотите открыть %1 файл?</numerusform>
            <numerusform>Вы хотите открыть все %1 файла?</numerusform>
            <numerusform>Вы хотите открыть все %1 файлов?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="118"/>
        <source>Other Applications</source>
        <translation>Другие приложения</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="125"/>
        <source>Create &amp;New</source>
        <translation>&amp;Создать</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="144"/>
        <source>&amp;Restore</source>
        <translation>&amp;Восстановить</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="154"/>
        <source>Cut</source>
        <translation>Вырезать</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="158"/>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="162"/>
        <source>Paste</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="166"/>
        <location filename="../filemenu.cpp" line="484"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Переместить в корзину</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="170"/>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="226"/>
        <source>Mount</source>
        <translation>Смонтировать</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="240"/>
        <source>Unmount</source>
        <translation>Размонтировать</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="254"/>
        <source>Eject</source>
        <translation>Извлечь</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="275"/>
        <source>Extract to...</source>
        <translation>Распаковать в...</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="283"/>
        <source>Extract Here</source>
        <translation>Распаковать здесь</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="290"/>
        <source>Compress</source>
        <translation>Сжать</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="299"/>
        <source>Properties</source>
        <translation>Свойства</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="313"/>
        <source>Trust selected executables</source>
        <translation>Доверять выбранным исполняемым файлам</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="314"/>
        <source>Trust this executable</source>
        <translation>Доверять этому исполняемому файлу</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="419"/>
        <source>Output</source>
        <translation>Вывод</translation>
    </message>
    <message>
        <location filename="../filemenu.cpp" line="148"/>
        <location filename="../filemenu.cpp" line="484"/>
        <source>&amp;Delete</source>
        <translation>&amp;Удалить</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../fileoperation.cpp" line="317"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="318"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Некоторые файлы не могут быть помещены в корзину, поскольку файловая система не поддерживает эту операцию.
Вы хотите удалить их вместо перемещения?</translation>
    </message>
    <message>
        <location filename="../fileoperation.cpp" line="404"/>
        <location filename="../fileoperation.cpp" line="422"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="405"/>
        <source>Do you want to delete the selected file(s)?</source>
        <translation>
            <numerusform>Вы хотите удалить выбранный файл?</numerusform>
            <numerusform>Вы хотите удалить выбранные файлы?</numerusform>
            <numerusform>Вы хотите удалить выбранные файлы?</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../fileoperation.cpp" line="423"/>
        <source>Do you want to move the selected file(s) to trash can?</source>
        <translation>
            <numerusform>Хотите переместить выделенный файл в корзину?</numerusform>
            <numerusform>Хотите переместить выделенные файлы в корзину?</numerusform>
            <numerusform>Хотите переместить выделенные файлы в корзину?</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../fileoperationdialog.cpp" line="46"/>
        <source>Move files</source>
        <translation>Перемещение файлов</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="47"/>
        <source>Moving the following files to destination folder:</source>
        <translation>Перемещение следующих файлов в папку назначения:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="50"/>
        <source>Copy Files</source>
        <translation>Копирование файлов</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="51"/>
        <source>Copying the following files to destination folder:</source>
        <translation>Копирование следующих файлов в папку назначения:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="54"/>
        <source>Trash Files</source>
        <translation>Перемещение файлов в корзину</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="55"/>
        <source>Moving the following files to trash can:</source>
        <translation>Перемещение следующих файлов в корзину:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="58"/>
        <source>Delete Files</source>
        <translation>Удаление файлов</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="59"/>
        <source>Deleting the following files:</source>
        <translation>Удаление следующих файлов:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="64"/>
        <source>Create Symlinks</source>
        <translation>Создание ссылок</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="65"/>
        <source>Creating symlinks for the following files:</source>
        <translation>Создание ссылок на следующие файлы:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="68"/>
        <source>Change Attributes</source>
        <translation>Изменение атрибутов</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="69"/>
        <source>Changing attributes of the following files:</source>
        <translation>Изменение атрибутов следующих файлов:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="74"/>
        <source>Restore Trashed Files</source>
        <translation>Восстановление файлов из корзины</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="75"/>
        <source>Restoring the following files from trash can:</source>
        <translation>Восстановление следующих файлов из корзины:</translation>
    </message>
    <message>
        <location filename="../fileoperationdialog.cpp" line="149"/>
        <location filename="../fileoperationdialog.cpp" line="155"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../filepropsdialog.cpp" line="162"/>
        <source>View folder content</source>
        <translation>Просмотр содержимого папки</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="163"/>
        <source>View and modify folder content</source>
        <translation>Просмотр и изменение содержимого папки</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="167"/>
        <source>Read</source>
        <translation>Чтение</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="168"/>
        <source>Read and write</source>
        <translation>Чтение и запись</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="170"/>
        <source>Forbidden</source>
        <translation>Запрещено</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="287"/>
        <source>Files of different types</source>
        <translation>Файлы разного типа</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="310"/>
        <location filename="../filepropsdialog.cpp" line="317"/>
        <location filename="../filepropsdialog.cpp" line="324"/>
        <source>N/A</source>
        <translation>---</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="328"/>
        <source>Multiple Files</source>
        <translation>Несколько файлов</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="405"/>
        <source>%p% used</source>
        <translation>%p% занято</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="406"/>
        <source>%1 Free of %2</source>
        <translation>%1 свободно из %2</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="452"/>
        <source>no file</source>
        <translation>нет файлов</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="454"/>
        <source>one file</source>
        <translation>1 файл</translation>
    </message>
    <message numerus="yes">
        <location filename="../filepropsdialog.cpp" line="456"/>
        <source>%Ln files</source>
        <translation>
            <numerusform>%Ln файл</numerusform>
            <numerusform>%Ln файла</numerusform>
            <numerusform>%Ln файлов</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="490"/>
        <location filename="../filepropsdialog.cpp" line="535"/>
        <source>Select an icon</source>
        <translation>Выберите значок</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="492"/>
        <location filename="../filepropsdialog.cpp" line="537"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation>Изображения (*.png *.xpm *.svg *.svgz )</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="643"/>
        <source>Apply changes</source>
        <translation>Применить изменения</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="644"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Вы хотите применить изменения рекурсивно ко всем файлам и подпапкам?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../filesearchdialog.cpp" line="152"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="152"/>
        <source>You should add at least one directory to search.</source>
        <translation>Вы должны добавить не менее одного каталога для поиска.</translation>
    </message>
    <message>
        <location filename="../filesearchdialog.cpp" line="159"/>
        <source>Select a folder</source>
        <translation>Выберите папку</translation>
    </message>
</context>
<context>
    <name>Fm::FileTransferJob</name>
    <message>
        <location filename="../core/filetransferjob.cpp" line="479"/>
        <source>Cannot copy a directory into itself!</source>
        <translation>Невозможно скопировать каталог внутрь себя самого!</translation>
    </message>
    <message>
        <location filename="../core/filetransferjob.cpp" line="530"/>
        <source>Cannot create a link on non-native filesystem</source>
        <translation>Файловая система не поддерживает создание ссылок</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../foldermenu.cpp" line="57"/>
        <source>Empty Trash</source>
        <translation>Очистить корзину</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="69"/>
        <source>Create &amp;New</source>
        <translation>&amp;Создать</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="74"/>
        <source>&amp;Paste</source>
        <translation>&amp;Вставить</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="87"/>
        <source>Select &amp;All</source>
        <translation>Выделить &amp;всё</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="91"/>
        <source>Invert Selection</source>
        <translation>Инвертировать выделение</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="98"/>
        <source>Sorting</source>
        <translation>Сортировка</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="103"/>
        <source>Show Hidden</source>
        <translation>Показать скрытые</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="138"/>
        <source>Folder Pr&amp;operties</source>
        <translation>&amp;Свойства папки</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="181"/>
        <source>Output</source>
        <translation>Вывод</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="203"/>
        <source>By File Name</source>
        <translation>По имени</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="204"/>
        <source>By Modification Time</source>
        <translation>По времени изменения</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="205"/>
        <source>By Creation Time</source>
        <translation>По времени создания</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="208"/>
        <source>By Deletion Time</source>
        <translation>По времени удаления</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="211"/>
        <source>By File Size</source>
        <translation>По размеру</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="212"/>
        <source>By File Type</source>
        <translation>По типу</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="213"/>
        <source>By File Owner</source>
        <translation>По владельцу</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="214"/>
        <source>By File Group</source>
        <translation>По группе файла</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="220"/>
        <source>Ascending</source>
        <translation>Возрастающая</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="225"/>
        <source>Descending</source>
        <translation>Убывающая</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="242"/>
        <source>Folder First</source>
        <translation>Сначала папки</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="250"/>
        <source>Hidden Last</source>
        <translation>Скрытые в конце</translation>
    </message>
    <message>
        <location filename="../foldermenu.cpp" line="258"/>
        <source>Case Sensitive</source>
        <translation>Учитывать регистр</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../foldermodel.cpp" line="307"/>
        <source>Location:</source>
        <translation>Расположение:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="311"/>
        <source>File type:</source>
        <translation>Тип файла:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="316"/>
        <source>File size:</source>
        <translation>Размер файла:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="320"/>
        <source>Last modified:</source>
        <translation>Последнее изменение:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="321"/>
        <source>Last accessed:</source>
        <translation>Последний доступ:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="322"/>
        <source>N/A</source>
        <translation>---</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="324"/>
        <source>Created:</source>
        <translation>Создан:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="329"/>
        <source>Owner:</source>
        <translation>Владелец:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="330"/>
        <source>Group:</source>
        <translation>Группа:</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="397"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="400"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="403"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="406"/>
        <source>Modified</source>
        <translation>Изменён</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="409"/>
        <source>Created</source>
        <translation>Создан</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="412"/>
        <source>Deleted</source>
        <translation>Удалён</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="415"/>
        <source>Owner</source>
        <translation>Владелец</translation>
    </message>
    <message>
        <location filename="../foldermodel.cpp" line="418"/>
        <source>Group</source>
        <translation>Группа</translation>
    </message>
</context>
<context>
    <name>Fm::FolderViewTreeView</name>
    <message>
        <location filename="../folderview.cpp" line="406"/>
        <source>Auto-resize columns</source>
        <translation>Автоподбор ширины столбцов</translation>
    </message>
    <message>
        <location filename="../folderview.cpp" line="423"/>
        <source>Visible Columns</source>
        <translation>Видимые столбцы</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Жирный</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Курсив</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../mountoperationpassworddialog.cpp" line="40"/>
        <source>&amp;Connect</source>
        <translation>&amp;Соединить</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../pathbar.cpp" line="134"/>
        <source>&amp;Edit Path</source>
        <translation>&amp;Редактировать путь</translation>
    </message>
    <message>
        <location filename="../pathbar.cpp" line="137"/>
        <source>&amp;Copy Path</source>
        <translation>&amp;Копировать путь</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../placesmodel.cpp" line="46"/>
        <source>Places</source>
        <translation>Места</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="54"/>
        <source>Desktop</source>
        <translation>Рабочий стол</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="60"/>
        <source>Computer</source>
        <translation>Компьютер</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="68"/>
        <source>Applications</source>
        <translation>Приложения</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="77"/>
        <source>Network</source>
        <translation>Сеть</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="81"/>
        <source>Devices</source>
        <translation>Устройства</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="136"/>
        <source>Bookmarks</source>
        <translation>Закладки</translation>
    </message>
    <message>
        <location filename="../placesmodel.cpp" line="227"/>
        <source>Trash</source>
        <translation>Корзина</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../placesview.cpp" line="557"/>
        <source>Empty Trash</source>
        <translation>Очистить корзину</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="542"/>
        <source>Open in New Tab</source>
        <translation>Открыть в новой вкладке</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="545"/>
        <source>Open in New Window</source>
        <translation>Открыть в новом окне</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="577"/>
        <location filename="../placesview.cpp" line="639"/>
        <source>Hide</source>
        <translation>Скрыть</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="594"/>
        <source>Move Bookmark Up</source>
        <translation>Сдвинуть закладку вверх</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="601"/>
        <source>Move Bookmark Down</source>
        <translation>Сдвинуть закладку вниз</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="606"/>
        <source>Rename Bookmark</source>
        <translation>Переименовать закладку</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="610"/>
        <source>Remove Bookmark</source>
        <translation>Удалить закладку</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="620"/>
        <location filename="../placesview.cpp" line="653"/>
        <source>Unmount</source>
        <translation>Отключить</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="624"/>
        <source>Mount</source>
        <translation>Подключить</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="630"/>
        <source>Eject</source>
        <translation>Извлечь</translation>
    </message>
    <message>
        <location filename="../placesview.cpp" line="665"/>
        <source>Show All Entries</source>
        <translation>Показать все элементы</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../renamedialog.cpp" line="58"/>
        <location filename="../renamedialog.cpp" line="77"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Тип: %1
Размер: %2
Изменён: %3</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="64"/>
        <location filename="../renamedialog.cpp" line="83"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Тип: %1
Изменён: %2</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="96"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Перезаписать</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="98"/>
        <source>&amp;Rename</source>
        <translation>&amp;Переименовать</translation>
    </message>
    <message>
        <location filename="../renamedialog.cpp" line="108"/>
        <source>&lt;p&gt;&lt;b&gt;The file cannot overwrite itself.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Please select another name.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Файл не может перезаписать себя.&lt;/b&gt;&lt;/p&gt;&lt;p&gt;Выберите другое имя.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../sidepane.cpp" line="45"/>
        <source>Lists</source>
        <translation>Списки</translation>
    </message>
    <message>
        <location filename="../sidepane.cpp" line="46"/>
        <source>Directory Tree</source>
        <translation>Дерево каталогов</translation>
    </message>
</context>
<context>
    <name>Fm::UntrashJob</name>
    <message>
        <location filename="../core/untrashjob.cpp" line="35"/>
        <source>Cannot untrash file &apos;%s&apos;: original path not known</source>
        <translation>Не удаётся восстановить файл «%s»: не найден первоначальный путь</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Подключить</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>Подключиться &amp;анонимно</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>Подключиться как &amp;пользователь:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="79"/>
        <source>&amp;Username:</source>
        <translation>&amp;Имя пользователя:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="102"/>
        <source>&amp;Password:</source>
        <translation>&amp;Пароль:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="112"/>
        <source>&amp;Domain:</source>
        <translation>&amp;Домен:</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>Забыть пароль &amp;сразу</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="137"/>
        <source>Remember password for &amp;this session</source>
        <translation>Запоминать пароли для &amp;текущей сессии</translation>
    </message>
    <message>
        <location filename="../mount-operation-password.ui" line="147"/>
        <source>Remember &amp;forever</source>
        <translation>Запомнить &amp;навсегда</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../filelauncher.cpp" line="124"/>
        <location filename="../filepropsdialog.cpp" line="669"/>
        <location filename="../mountoperation.cpp" line="297"/>
        <location filename="../utilities.cpp" line="150"/>
        <location filename="../utilities.cpp" line="289"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="166"/>
        <source>Rename File</source>
        <translation>Переименовать файл</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="167"/>
        <source>Please enter a new name:</source>
        <translation>Введите новое имя:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="226"/>
        <source>Create Folder</source>
        <translation>Создать папку</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="231"/>
        <source>Please enter a new file name:</source>
        <translation>Введите имя нового файла:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="232"/>
        <source>New file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="236"/>
        <source>Please enter a new folder name:</source>
        <translation>Введите имя новой папки:</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="237"/>
        <source>New folder</source>
        <translation>Новая папка</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="242"/>
        <source>Enter a name for the new %1:</source>
        <translation>Введите имя нового файла (%1):</translation>
    </message>
    <message>
        <location filename="../utilities.cpp" line="227"/>
        <source>Create File</source>
        <translation>Создать файл</translation>
    </message>
    <message>
        <location filename="../filepropsdialog.cpp" line="687"/>
        <source>Custom Icon Error</source>
        <translation>Ошибка пользовательского значка</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="41"/>
        <source>The path is not mounted.</source>
        <translation>Путь не примонтирован.</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="319"/>
        <source>Invalid desktop entry file: &apos;%1&apos;</source>
        <translation>Неверный файл .desktop: «%1»</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="355"/>
        <source>No default application is set to launch &apos;%1&apos;</source>
        <translation>Не задано приложение по умолчанию для открытия «%1»</translation>
    </message>
    <message>
        <location filename="../core/basicfilelauncher.cpp" line="396"/>
        <source>Cannot set working directory to &apos;%1&apos;: %2</source>
        <translation>Не удалось задать рабочий каталог «%1»: %2</translation>
    </message>
    <message>
        <location filename="../placesmodelitem.cpp" line="127"/>
        <source>Identifier: </source>
        <translation>Устройство: </translation>
    </message>
    <message>
        <location filename="../foldermodelitem.cpp" line="61"/>
        <location filename="../foldermodelitem.cpp" line="74"/>
        <source>N/A</source>
        <translation>---</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Подтвердить замену файлов</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;В этом месте назначения уже есть файл с таким именем.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Вы хотите заменить существующий файл?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="63"/>
        <source>with the following file?</source>
        <translation>следующим файлом?</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>&amp;Имя файла:</translation>
    </message>
    <message>
        <location filename="../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Запомнить выбор для всех уже существующих файлов</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Искать файлы</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>Имя/Расположение</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Шаблоны имени файла:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="44"/>
        <source>*</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="58"/>
        <source>Use regular expression</source>
        <translation>Использовать регулярные выражения</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="71"/>
        <source>Places to Search:</source>
        <translation>Места для поиска:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="84"/>
        <source>&amp;Add</source>
        <translation>&amp;Добавить</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="96"/>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="132"/>
        <source>Search for hidden files</source>
        <translation>Искать скрытые файлы</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="143"/>
        <source>File Type</source>
        <translation>Тип файла</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="149"/>
        <source>Only search for files of following types:</source>
        <translation>Искать файлы только следующих типов:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="155"/>
        <source>Text files</source>
        <translation>Текстовые файлы</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="162"/>
        <source>Image files</source>
        <translation>Изображения</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="169"/>
        <source>Audio files</source>
        <translation>Аудиофайлы</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="176"/>
        <source>Video files</source>
        <translation>Видеофайлы</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="183"/>
        <source>Documents</source>
        <translation>Документы</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="190"/>
        <source>Folders</source>
        <translation>Папки</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="214"/>
        <source>Content</source>
        <translation>Содержание</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="220"/>
        <source>File contains:</source>
        <translation>Файл содержит:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="240"/>
        <source>&amp;Use regular expression</source>
        <translation>&amp;Использовать регулярные выражения</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="267"/>
        <source>Properties</source>
        <translation>Свойства</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="273"/>
        <source>File Size:</source>
        <translation>Размер файла:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="302"/>
        <source>Larger than:</source>
        <translation>Больше, чем:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="316"/>
        <location filename="../filesearch.ui" line="346"/>
        <source>Bytes</source>
        <translation>Байт</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="321"/>
        <location filename="../filesearch.ui" line="351"/>
        <source>KiB</source>
        <translation>КиБ</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="326"/>
        <location filename="../filesearch.ui" line="356"/>
        <source>MiB</source>
        <translation>МиБ</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="331"/>
        <location filename="../filesearch.ui" line="361"/>
        <source>GiB</source>
        <translation>ГиБ</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="281"/>
        <source>Smaller than:</source>
        <translation>Меньше, чем:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="51"/>
        <source>Case sensitive</source>
        <translation>Учитывать регистр</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="125"/>
        <source>Search in subdirectories</source>
        <translation>Искать в подкаталогах</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="233"/>
        <source>Case sensiti&amp;ve</source>
        <translation>Учитывать &amp;регистр</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="377"/>
        <source>Last Modified Time:</source>
        <translation>Время последнего изменения:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="385"/>
        <source>Earlier than:</source>
        <translation>Раньше, чем:</translation>
    </message>
    <message>
        <location filename="../filesearch.ui" line="392"/>
        <source>Later than:</source>
        <translation>Позже, чем:</translation>
    </message>
</context>
</TS>
